"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseYamlFiles = void 0;
const js_yaml_1 = __importDefault(require("js-yaml"));
const Result_1 = require("./types/Result");
async function parseYamlFiles(files) {
    const parsedFiles = {};
    const failures = {};
    function parseFilePath(file) {
        try {
            const parsed = js_yaml_1.default.load(file.fileContents);
            parsedFiles[file.filepath] = parsed;
        }
        catch (error) {
            failures[file.filepath] = {
                type: Result_1.WorkspaceParserFailureType.FILE_PARSE,
                error,
            };
        }
    }
    await Promise.all(files.map(parseFilePath));
    if (Object.keys(failures).length > 0) {
        return {
            didSucceed: false,
            failures,
        };
    }
    else {
        return {
            didSucceed: true,
            files: parsedFiles,
        };
    }
}
exports.parseYamlFiles = parseYamlFiles;
